      subroutine hec_dig_read_weights
c
c read weights for amplitude and time reconstruction from 
c files: 
c dig_weight_amp.dat   --  amplitude reconstruction
c dig_weight_tim.dat   --  time of max reconstruction
c
      implicit none
c
      include'hec_par.inc'      ! shared parameters
      include'hec_geo.inc'      ! geometry correspondence tables 
      include'hec_dig_sys.inc'  ! digital filtering system common
c
c local variables
c
      integer ic, i_t, iw
      integer ios
      integer weight_version_tim
c
c open amplitude reconstruction coefficient file 
c
      open(unit=10,file='dig_weights_amp.dat',status='OLD')
c
c read:
c weight_version --> what version of the weights is this (date)
c nslice_dig --> number of time slices used in filtering
c iwmax      --> number of weights needed to be read from file to calculate
c                the weights for one channel
c dig_tzero  --> the first time slice used in the fit
c
      read (10,*,ERR=200,END=300) weight_version
      read (10,fmt='(I1)',ERR=200,END=300) nslice_dig
      read (10,fmt='(I1)',ERR=200,END=300) iwmax
      read (10,fmt='(I1)',ERR=200,END=300) dig_tzero
c
c echo version to output
c
      print *, ' '
      print *, ' *** reading digital filtering coefficients for version'
     +          ,weight_version
c     
c read coefficients for amplitude weights 
c
      do ic = 1, i_adc_used
        do i_t = 1, nslice_dig
          read(10,fmt='(5G14.7)',iostat=ios,ERR=200,END=300)
     &                            ( dig_amp_par(ic,i_t,iw), iw=1,iwmax)
        enddo
      enddo
      close(10)      
c
c open time reconstruction coefficient file 
c
      open(unit=10,file='dig_weights_tim.dat',status='OLD')
c
c read:
c weight_version --> what version of the weights is this (date)
c nslice_dig --> number of time slices used in filtering
c iwmax      --> number of weights needed to be read from file to calculate
c                the weights for one channel
c dig_tzero  --> the first time slice used in the fit
c
      read (10,*,ERR=200,END=300) weight_version_tim
      read (10,fmt='(I1)',ERR=200,END=300) nslice_dig
      read (10,fmt='(I1)',ERR=200,END=300) iwmax
      read (10,fmt='(I1)',ERR=200,END=300) dig_tzero
c     
c read coefficients for time weights 
c
      if (weight_version_tim .ne. weight_version) then
        print *,'ERROR: hec_dig_read_weights: version of time recon.',
     +          'weights does not match amplitude version'
        stop
      endif
      do ic = 1, i_adc_used
        do i_t = 1, nslice_dig
          read(10,FMT='(5G14.7)',IOSTAT=ios,ERR=200,END=300)
     &                            ( dig_tim_par(ic,i_t,iw), iw=1,iwmax)
        enddo
      enddo
      close(10)
ccc
ccc debug print
ccc
ccc      do ic = 1, i_adc_used
ccc        do i_t = 1, nslice_dig
ccc          write(6,'(5G14.7)') ( dig_tim_par(ic,i_t,iw), iw=1,iwmax)
ccc        enddo
ccc      enddo
ccc
c
c check for read errors
c
      return
 300  continue
      print *,'hec_dig_read_weights.f: error reading digital filtering',
     +         'weights -- premature end of file -- stopping'
      stop
 200  continue
      print *,'hec_dig_read_weights.f: error reading digital filtering',
     +         'weights -- stopping'
      stop
c
      end

