      subroutine hec_bad_cells
c
c routine looks at calibration and digital filtering weights to 
c fill bad cell list
c
c in hec_geo.inc
c n_badcells      number of "bad cells" in this run 
c i_badcells_ic   2-d (i,flag) array giving ic, flag for all bad cells
c                 i     = bad cells index (counter)
c                 flag  = 1 value of array is ic number
c                       = 2 value of array is calibration flag
c                           (0=good,1=no calibration,2=bad calibration)
c                       = 3 value or array is digital weights flag
c                           (0=good,1=bad weights)
c
      implicit none
c
      include'hec_par.inc'      !shared parameters
      include'hec_cal.inc'      !calibrated energies
      include'hec_cal_coef.inc' !calibration coefficients
      include'hec_datacard.inc' !datacard values
      include'hec_dig.inc'      !digital filtering common
      include'hec_dig_sys.inc'  !digital filtering system common
      include'hec_geo.inc'      !geometry correspondence tables
c
c local variables
c
      integer ic,iw,i_t,cflag
      logical cbad, dbad
c
      n_badcells = 0
      call vzero(i_badcells_ic, i_adc_dim*3)
c
c read digital filtering weights
c
      if (mk_dig .gt. 0) call hec_dig_read_weights
c
c read calibration coefficients
c
      if (io_cal(1) .gt. 0) call hec_cal_read
c
c loop over cells
c
      do ic = 1, i_adc_used
      
c look for bad (non-existent) digital filtering weights
c issue warning for channels with at least one null coefficient for 
c amplitude reconstruction
c
        dbad = .false.
        if (mk_dig .gt. 0) then
          do i_t = 1, nslice_dig
            do iw = 1, iwmax
              if (dig_amp_par(ic,i_t,iw) .eq. 0.) dbad = .true.
            enddo
          enddo
          if (dbad) then
            print *,' *** WARNING no filtering weights for channel ', ic
          endif
        endif
c
c look for cells with bad calibration
c issue warning for channels with bad calibration
c
        cbad = .false.
        if (io_cal(1) .gt. 0) then
          if (hec_cal_coef(ic, 5) .ne. 1) then
            cbad = .true.
            if (hec_cal_coef(ic, 5) .eq. 0) then
              cflag = 1
            else
              cflag = 2
            endif
          endif
          if (cbad) then
            print *,
     +      ' *** WARNING bad/non-existent calibration, channel ', ic
          endif
        endif
c
c fill array with flags for each bad ic
c
        if (dbad .or. cbad) then
          n_badcells = n_badcells + 1
          i_badcells_ic(n_badcells, 1) = ic
          if (cbad) then
            i_badcells_ic(n_badcells, 2) = cflag
          endif
          if (dbad) then
            i_badcells_ic(n_badcells, 3) = 1
          endif
        endif
      enddo
c
      return
      end



