      subroutine hec_geo_jun99
c
c fill geometry table and physics database array 
c June 1999                                     
c                                                
c lookup table read from file (ic is ADC#)
c        lookup(ic,1) = ic    
c        lookup(ic,2) = i_pad   
c        lookup(ic,3) = i_z     
c        lookup(ic,4) = i_eta   
c        lookup(ic,5) = i_phi  
c        lookup(ic,6) = i_mod  
c        lookup(ic,7) = i_seg  
c
      implicit none
c
      include'hec_par.inc'      ! parameter common
      include'hec_datacard.inc' ! datacard values
      include'hec_geo.inc'      ! geometry common
      include'hec_runh.inc'     ! run header
      include'hec_tdc.inc'      ! tdc
c
c local variable
c
      character fname*19, ctag*3
      integer fnum, ios
      parameter (fnum=20, fname='hec_geo.dat')
      integer n_tdc_dim
      parameter (n_tdc_dim = 15 )
      integer run_list(n_tdc_dim)
      integer br_points(n_tdc_dim)
      integer i_look_dim
      parameter (i_look_dim = 7)
      integer lookup(i_adc_dim, i_look_dim) 		! lookup table
      integer i, j, ic, i_mod, i_seg, i_pad, i_eta, i_phi, i_z
c
c TDC corrections
c run    br_point for that run
c 8167    1455
c 8177    1442
c 8187    1448
c 8195    1442
c 8210    1426
c 8225    1442
c 8260    1436
c 8264    2088
c 8267    2092
c 8275    2099
c 8286    2096
c 8293    2107
c 8303    2099
c 8343    2110
c 8353    2099
c 
      data run_list  /8167,8177,8187,8195,8210,8225,8260,8264,
     +                8267,8275,8286,8293,8303,8343,8353/
      data br_points /1455,1442,1448,1442,1426,1442,1436,2088,
     +                2092,2099,2096,2107,2099,2110,2099/
c
c reset geometry
c
      call vzero (ictodb, 3*i_adc_dim)
      call vzero (ictoph, 3*i_adc_dim)
      call vzero (dbtoic, i_mod_max*i_seg_max*i_pad_max)
      call vzero (phtoic, i_mod_max*i_seg_max*i_pad_max)
      call vzero (lookup, i_look_dim*i_adc_dim)
c
      i_adc_used = 300 				! set geometry used
      i_tim_used = 16
c
      i_mod_used = 3
      i_seg_used = 4
      i_pad_used = 24
c
      i_eta_used = 14
      i_phi_used = 6
      i_z_used   = 4
c
      tdc_raw_to_ns = 18.1/1000.
c
c read database file
c
      open (UNIT=fnum,IOSTAT=ios,ERR=100,FILE=fname,
     &                STATUS='OLD',
     &                ACCESS='SEQUENTIAL',FORM='FORMATTED')
c
c skip header and look for geometry table
c
      ctag = 'xxx'
      do while (ctag .ne. 'geo')
        read(fnum,FMT='(a3)',IOSTAT=ios,ERR=100,END=300) ctag
      enddo
c
c read table
c
      do i = 1, i_adc_used
        read(fnum,FMT='(7I7)',IOSTAT=ios,ERR=100,END=300)
     &  ( lookup(i,j), j=1, i_look_dim)
        if (i.ne.lookup(i,1)) then 			! check lookup table
          print *, ' *** inconsistent database file at ic', i
          print *, ' *** database: ',(lookup(i,j) ,j=1, i_look_dim)
          stop
        endif 						! if (i.ne.lookup(i,1)) then
      enddo 						! do i=1, i_adc_used
c         
      close(fnum)               ! close database file
c
c fill tables
c
      do ic=1, i_adc_used
c
        i_mod = lookup(ic,6)
        i_seg = lookup(ic,7)
        i_pad = lookup(ic,2)
c
        ictodb(ic,1) = i_mod
        ictodb(ic,2) = i_seg
        ictodb(ic,3) = i_pad
        if ((i_mod.eq.0).or.(i_seg.eq.0).or.(i_pad.eq.0)) then
          continue 					! unconnected ADC
        else
          dbtoic(i_mod,i_seg,i_pad) = ic
        endif 						! if ((i_mod.eq.0).or.(i
c
        i_eta = lookup(ic,4)
        i_phi = lookup(ic,5)
        i_z   = lookup(ic,3)
c
        ictoph(ic,1) = i_eta
        ictoph(ic,2) = i_phi
        ictoph(ic,3) = i_z
        if ((i_eta.eq.0).or.(i_phi.eq.0).or.(i_z.eq.0)) then
          continue					! unconnected ADC
        else
          phtoic(i_eta,i_phi,i_z) = ic
        endif 						! if ((i_eta.eq.0).or...
      enddo 						! do ic=1, i_adc_used
c
      print *, ' *** June 99 geometry correspondence tables filled'
c
c if running in offline mode, read tdc correction (online we make no 
c such correction
c
      if (run_mode .eq. 1) then
c
c look for run number
c
         call hec_runh_pass
c
c look for tdc break point position for this run
c
         tdc_br_point = -1
         do i= n_tdc_dim, 1, -1
           if (tdc_br_point.lt.0 .and. run_no.ge.run_list(i)) then
             tdc_br_point = br_points(i)
           endif
         enddo
         if (tdc_br_point.lt.0) then
           print *,' *** hec_geo_jun99: wrong run_no for this period'
            stop
         endif
         print *, ' *** tdc breakpoint used for run number ', run_no, 
     +            ' is ', tdc_br_point
      endif
c
      return
c
c treat end of file problems
c
 100  continue
      close(fnum)               ! close database file
      print *, ' *** error accessing June 99 geometry file'
      stop
c
 300  continue
      close(fnum)               ! close database file
      print *, ' *** problems reading June 99 geometry tables'
      stop
c
      end


