      logical function hec_nextevt_epio(irecbuf,iepbuf)
c
c read next event from data and save into common blocks
c in include files
c
c hec_nextevt_epio = .true.  => event read successfully
c                  = .false. => event read successfully and eof
c
c     Author: 07.04.97   Dieter Striegel
c   modified: 29.04.97   Dugan O'Neil
c
      implicit none
c
      include'hec_par.inc'      !shared parameters
      include'hec_datacard.inc' !datacard values
      include'hec_epio.inc'     !epio
      include'hec_evth.inc'     !event header
      include'hec_online.inc'   !online mode 
      include'hec_runh.inc'     !run header
      include'hec_stats_epio.inc' !epio banks stats
c
c set the maximum number of records to search for the first
c record containing an event header bank
c
      integer maxrecords
      parameter (maxrecords = 10)
c
c set the maximum number of banks expected in a record
c
      integer maxsubl
      parameter (maxsubl = 10)
c
c local variable declarations
c      
      integer i, ib, id, ierr, nw, len
      integer irecords, nbank, lenrec
c
      integer lbank(maxsubl)
      logical getmore
      logical b_runh, b_geoe
c
c dimension epio buffer arrays
c
      integer*2 irecbuf, iepbuf
      dimension irecbuf(lrecbuf), iepbuf(lepbuf)
c
c we are looking for 
c - the run header bank
c - the event header bank
c - the adc values bank
c start by assuming we have none
c
      b_runh = .false.
      b_geoe = .false.
c
c loop over all records, until a record starting with an
c event header bank is found
c
      irecords = 0
      getmore = .true.
      do while (irecords .lt.  maxrecords .and. getmore)
c
c call epio reading
c
        call epread(in_typ(2), 20, nw, irecbuf, iepbuf, ierr)
        if (ierr.eq.0) then
         call epfrd(in_typ(2), 11, nw, irecbuf, iepbuf, ierr)
        endif
ccc        call epread(in_typ(2), 1, nw, irecbuf, iepbuf, ierr)
c
c correct for bad run header in May 96
c
        if (irunpd .eq. 1 .and. irecbuf(3) .eq. id_runh) then
         irecbuf(1) = 14
         irecbuf(2) = irecbuf(1) - 2
        endif
ccc
c        print *, ' number of words in epio record ', irecbuf(1)
c        write(*, '(10i6)') (irecbuf(i), i = 1, irecbuf(1))
ccc        call hec_dump_epio
c
        if (ierr .eq. 1) then
c
c end of file
c
          hec_nextevt_epio = .false.
          eorflag = .true.
          print *, ' *** end of epio file reached'
          return
c
         elseif (ierr .ne. 0) then
c
c epread error
c
c check if online mode - if so return instead of stopping
c
           print *, ' *** epread error in hec_nextevt_epio', ierr
           stop
c
         else        
c
c count number of records read
c
           irecords = irecords + 1
c
c get first bank
c
           len = irecbuf(2)
           do i = 1, min(len + 1, lrecbuf)
             ibankbuf(i) = irecbuf(1 + i)
           enddo
c
c get id and pointer of first bank in record
c
           id = ibankbuf(2)
c
c if it is a run header bank, fill RUNH common
c
           if (id .eq. id_runh) then 			
             call hec_runh_epio
             b_runh = .true.
c     
c slow control bank, in case it comes separately from event
c
c           elseif (id .eq. 70) then
c             len = irecbuf(2) 	
c             nwords = (len - 4)/2 + 1
c             do j = 1, nwords
c                hv(j) = irecbuf(4 + j)          !hi voltage
c                hi(j) = irecbuf(4 + nwords + j) ! current	
c             enddo
c
c record starts with event header
c this is a proper event record
c
           elseif (id .eq. id_evth) then 
             getmore=.false.
           endif
         endif
       enddo
c
c check that we have found an event header, if not, stop
c
      if (irecords .ge. maxrecords) then
        print *, ' *** no event record found in hec_nextevt_epio'
        stop
      endif
c
c find pointers to banks in event record
c
      getmore = .true.
      nbank = 0
      ipointep = 2
      do while (nbank .lt. maxsubl .and. getmore)
        len = irecbuf(ipointep) 
c     
        if (len .lt. 1) then
          print *,' *** bad bank length in hec_nextevt_epio', len
          stop
        endif
c     
        len = len + 1
        nbank = nbank + 1
        lbank(nbank)= ipointep
        ipointep = ipointep + len
c
c make sure not to go past end of record
c fixes for particular run periods
c
        lenrec = irecbuf(1)
        if (irunpd .eq. 1 .or. irunpd .eq. 3) then
          if (ipointep .lt. lenrec - 1) then
            getmore = .true.
          else
            getmore = .false.
          endif
        else
          if (ipointep - 2 .lt. lenrec - 1) then
            getmore = .true.
          else
            getmore = .false.
          endif
        endif
      enddo
c
c for this event record, loop over banks and fill commons
c
      do ib = 1, nbank
c
c get pointer to the beginning of current bank
c
         ipointep = lbank(ib)
c
c get current bank
c
         len = irecbuf(ipointep)
         do i = 1, min(len + 1, lrecbuf)
           ibankbuf(i) = irecbuf(ipointep - 1 + i)
         enddo
c
c get bank id
c
         id = ibankbuf(2)
c
c event header bank
c
         if (id .eq. id_evth) then 
           call hec_evth_epio
           stat_evth = stat_evth + 1
c
c beam chamber bank
c
         elseif (id .eq. id_dwpc) then
           call hec_dwpc_epio
           stat_dwpc = stat_dwpc + 1
c
c adc values bank
c
         elseif (id .eq. id_geoe_96 .or. id .eq. id_geoe_97) then
           call hec_geoe_epio
           stat_geoe = stat_geoe + 1
           b_geoe = .true.
c
c fadc values bank
c
ccc         elseif (id .eq. id_fadc) then
ccc           call hec_fadc_epio
ccc           stat_fadc = stat_fadc + 1
c
c tdc values bank
c
         elseif (id .eq. id_tdc) then
           call hec_tdc_epio
           stat_tdc = stat_tdc + 1
         endif       
c
       enddo
c
c check conditions for good event
c event header has been found
c just check:
c    for first event, need run header and adc values
c    for other events, need adc values
c
       if (calo_on_flag) then
          if (i_event .eq. 1) then
             hec_nextevt_epio = b_runh .and. b_geoe
          else
             hec_nextevt_epio = b_geoe
          endif
       else
          if (i_event .eq. 1) then
             hec_nextevt_epio = b_runh 
          endif
          hec_nextevt_epio = .true.
       endif
c
       if (.not. hec_nextevt_epio) then
           print *, ' *** bad event structure in hec_nextevt_epio'
           stop
       endif
c
       end
      








