      subroutine hec_online_interface
c
c provides online interface in "autorun" mode
c never called from regular hec_adc package
c
c This routine opens and existing hbook file
c full of online histograms and gives the user 
c access to them in the same style as regular 
c online running.
c
c The only include files which are used contain
c parameters and histogram ids....this routine 
c does not depend on any stored values in common 
c blocks, thereby making it pseudo-independent from 
c hec_adc. 
c It is currently called from a program
c in the onlinescr directory and is used only on shift 
c at testbeam.
c
      implicit none
c
c online histogram common and parameter common
c This is shared with normal online running mode
c
      include'hec_par.inc'           ! shared parameters
      include'hec_his_sys.inc'       ! online histogram ids
c
c local variables
c
      integer maxcell
      parameter (maxcell=6)
      integer high_ic(maxcell),ic
      integer hisnum
      integer istat
c
      integer run_number
c
      integer hisorg
c
      character*5 chidh
      character*20 comment
      logical psbutton, zoombutton, gaussbutton, zonebutton, zoomstatus
c
      real sigpar(3),chi2, par(3)
      integer cur_zone, pic_count
c
c declare hbook functions
c
      real hmax,hstati
      external hmax,hstati
c
c access existing hbook file
c
      call hropen(35, 'hec_online', 
     +  'hec_online.hbook', ' ', 1024, istat)
      if (istat .ne. 0) then
        print *, '*** problem opening online hbook file ***',
     +  istat
        stop
      endif
c
c read histograms into memory
c
      call hcdir('//hec_online',' ')
      call hrin(0,0,0)
c
c initialize HPLOT graphical environment (for X11)
c
      call hplint(1)
c
c get list of 5 highest energy cells
c
      open(40,file="highcell.list",status="OLD")
      read(40, *) run_number
      read(40, '(1x,5i3)') (high_ic(ic), ic = 1, 5)
      read(40,*) high_ic(6)
      close(40)      
c
c start with a zone 1 2 noise plot
c
      call igmeta(0,0)
      call hec_online_hisdispl(9990,high_ic,run_number,zoomstatus)
      call iuwk(0,1)
      call igterm
c
c list histogram menu
c
      call hec_online_menu
c
c open user summary ps file
c
      open(unit=10,file='user_summary.ps',form='formatted',
     +status='unknown')
c
      cur_zone = 1
      call hplint(1)
      call hplopt('STAT',1)
c
c while the user has not entered 0 as a histogram number
c
      hisnum = -1
      pic_count = 0
      do while (hisnum .ne. 0)
        if (cur_zone .eq. 1) then
          call hplzon(1,1,1,' ')
          pic_count = 0
        elseif (cur_zone .eq. 2) then
          if (pic_count .eq. 4) then
            pic_count = 0
          endif
          if (pic_count .eq. 0) then
            call hplzon(2,2,pic_count+1,' ')
            pic_count = pic_count + 1
          else
            call hplzon(2,2,pic_count+1,'S')
            pic_count = pic_count + 1
          endif          
        endif

c
c prompt user for histogram number and read from keyboard
c
        print *, ' ***ENTER 9999 TO LIST HISTOGRAMS'
        print *, ' ***ENTER HISTOGRAM NUMBER TO DISPLAY'
        print *, ' ***ENTER 0 TO GO TO PRINT MENU (EXIT HISTO MENU)'
        read(5,*,ERR=10) hisnum
c
        if (hisnum .ne. 0) then
          if (hisnum .eq. 15000) call hec_online_clus_menu(hisnum)
c
c reset flags
c
          psbutton = .false.
          zoombutton = .false.
          gaussbutton = .false.
          zonebutton = .false.

c
c send output to graphical window only
c
          call igmeta(0,-111)
c
c call routine which knows how to display each histogram (all the fancy 
c labels etc.)
c
          call hec_online_hisdispl(hisnum,high_ic,run_number,zoomstatus)
c
c display and read buttons if chosen histo is not a control or run 
c summary number
c
          if (abs(hisnum) .lt. 9000 .or. (abs(hisnum) .gt. 9989
     +        .and. abs(hisnum) .ne. 9999)) then
c
c instruct user
c
            print *,'############################################### '
            print *,'Click left mouse button on PS to add histogram',
     +        ' to user summary'
            print *,'############################################### '
            print *,'Click left mouse button on ZOOM to zoom on ', 
     +        'histogram'
            print *,'############################################### '
            print *,'Click left mouse button on GAUSS to fit Gaussian ', 
     +              'on histogram'
            print *,'############################################### '
            print *,'Click left mouse button on ZONE to change # of  ', 
     +              'plots per page (1->4 or 4->1)'
            print *,'############################################### '
            print *,'Click right mouse button on histogram to return ',
     +        'to histogram menu' 
            print *,'############################################### '
c
            call hec_online_hisbut(psbutton,zoombutton,gaussbutton,
     +        zonebutton)
          endif
c
c control over display is now given to HIGZ window and mouse
c as long as user always presses a button, the loop continues.
c right mouse button exits
c
c a zoom will change the current histogram number (hisnum), keep the
c original as hisorg
c
          zoomstatus = .false.
          hisorg = hisnum
          do while (psbutton .or. zoombutton .or. gaussbutton
     +              .or. zonebutton )
c
c if user has chosen zoom button, zoom on displayed plot
c
c zoomed plot has histo id > 1100000
c
            if (zoombutton) then
              hisnum = 9900
              call hec_online_hisdispl(hisnum,high_ic,run_number,
     +          zoomstatus)
              zoomstatus = .true.
c
c if user has chosen .ps button, put plot directly to ps (no display)
c
            elseif (psbutton) then
              call igmeta(-10,-111)
              call hec_online_hisdispl(hisnum,high_ic,run_number,
     +          zoomstatus)                
c
            elseif (gaussbutton) then
              par(1)= hmax(hisnum)
              par(2)= hstati(hisnum,1,' ',0)
              par(3)= hstati(hisnum,2,' ',0)
              call hfithn(hisnum,'g',' ',3,par,par,par,par,sigpar,chi2)
              call hec_online_hisdispl(hisnum,high_ic,run_number,
     +          zoomstatus)                
c
c if user presses zone button, change the zone to either 2,2 or 1,1....
c w
c
            elseif (zonebutton) then
              if (cur_zone .eq. 2) then
                call hplzon(1,1,1,' ')       
                cur_zone = 1
                print *,' '
                print *,'Changing Zone from 4/page to 1/page'
                print *,' '
              elseif (cur_zone .eq. 1) then
                call hplzon(2,2,1,' ')       
                cur_zone = 2
                print *,' '
                print *,'Changing Zone from 1/page to 4/page'
                print *,' '                
              endif
            endif
c
c if this routine has just zoomed 
c add a comment to the plot
c
            if (zoomstatus) then
              call izitoc(hisorg,chidh)
              comment = 'Zoom on '//chidh
              call hplsof(12.,18.2,comment,0.5,0.,0.,-1.)
            endif
c
c reset display to go only to screen (not .ps)
c
            call igmeta(0,-111)
c
c
c instruct user
c
            print *,'############################################### '
            print *,'Click left mouse button on PS to add histogram',
     +              ' to user summary'
            print *,'############################################### '
            print *,'Click left mouse button on ZOOM to zoom on ', 
     +              'histogram'
            print *,'############################################### '
            print *,'Click left mouse button on GAUSS to fit Gaussian ', 
     +              'on histogram'
            print *,'############################################### '
            print *,'Click left mouse button on ZONE to change # of  ', 
     +              'plots per page (1->4 or 4->1)'
            print *,'############################################### '
            print *,'Click right mouse button on histogram to return ',
     +               'to histogram menu' 
            print *,'############################################### '
c
c put the buttons on
c
            call hec_online_hisbut(psbutton,zoombutton,gaussbutton,
     +                             zonebutton)
c
          enddo
c
        endif
c
        call igterm
ccc        call igmeta(0,999)
c
c if no error (ie got to here) skip error handling block
c
        goto 11
 10     continue
        print *, ' ***Not a valid histogram number'
        hisnum = -1
 11     continue
c
      enddo
c
c terminate hplot
c
      call hplend
      close(unit=10)
c
c close hbook file
c
      call hrend('hec_online')
      call hdelet(0)
      close(35)
c
      return
      end
